#!/usr/bin/R

# Xavier Fernández i Marín
# http://xavier-fim.net
# dc feb 19 10:00:06 CET 2014


library(plyr)
library(ggplot2)
rm(list=ls())

D <- read.table("./MPDataset_MPDS2013b.csv", header=TRUE, sep=",")

# The idea is to transfer the relevant variables from D (untransformed) to d (transformed)


# Manage dates
d <- data.frame(country=D$countryname, date=as.Date(as.character(D$edate), format="%m/%d/%Y")) 


# Manage families of parties
pf <- as.character(D$parfam)
pf[pf=="0"] <- "Diverse"
pf[pf=="10"] <- "Green"
pf[pf=="20"] <- "Communist"
pf[pf=="30"] <- "Social democratic"
pf[pf=="40"] <- "Liberal"
pf[pf=="50"] <- "Christian democratic"
pf[pf=="60"] <- "Conservative"
pf[pf=="70"] <- "Nationalist"
pf[pf=="80"] <- "Agrarian"
pf[pf=="90"] <- "Ethinc and regional"
pf[pf=="95"] <- "Special issue"
pf[pf=="98"] <- "Diverse"
pf[pf=="999"] <- NA

d <- cbind(d, family=pf)


# Manage share of votes
d <- cbind(d, p.vote=D$pervote)


# Manage seats and create proportion of seats
d <- cbind(d, seats=D$absseat, N.seats=D$totseats)
d$seats[d$seats==999] <- NA
d$N.seats[d$N.seats==999] <- NA
d <- ddply(d, .(country, date), transform, p.seats=seats/N.seats)


# Reduce the complexity to families, but not parties
df <- ddply(d, .(country, date, family), summarize, p.seats=sum(p.seats))

str(d)
str(df)



# Save it for the analysis of Consensus data
cpm <- df
save(cpm, file="cpm-consensus.RData")
