#!/usr/bin/R

# Xavier Fernández i Marín
# http://xavier-fim.net
# dj. de febr. 20 17:07:07 CET 2020


# From https://correlatesofwar.org/data-sets/bilateral-trade


library(tidyr)
library(dplyr)
library(countrycode)
load("../details.RData")

orig <- read.table("COW_Trade_4.0/Dyadic_COW_4.0.csv",
                   sep = ",", head = TRUE, 
                   quote = '',
                   na.strings = "-9") %>%
  as_tibble()


trade <- orig %>%
  rename(Year = year) %>%
  mutate(Origin = countrycode(ccode1, origin = "cown", destination = "country.name")) %>%
  mutate(Destination = countrycode(ccode2, origin = "cown", destination = "country.name"))



# Flows are not corresponding, so flow1 and flow2 must be arranged
filter(trade, Origin == "United States" & Destination == "Canada" & Year == 1920)
filter(trade, Origin == "Canada" & Destination == "United States" & Year == 1920)


# Pre 200305
#trade <- bind_rows(
#  select(trade, Origin, Destination, Year, ImportsFromDestination = flow1),
#  select(trade, Origin = Destination, Destination = Origin, Year, ImportsFromDestination = flow2)) %>%
#  mutate(Origin = as.factor(Origin), Destination = as.factor(Destination))

# 200305
trade <- bind_rows(
  select(trade, Origin, Destination, Year, 
         ImportsFromDestination = flow1,
         ExportsToDestination = flow2),
  select(trade, Origin = Destination, Destination = Origin, Year, 
         ImportsFromDestination = flow2,
         ExportsToDestination = flow1)) %>%
  mutate(Origin = as.factor(Origin), Destination = as.factor(Destination))



trade <- trade %>%
  filter(Year %in% years[1]:years[2])


# Add all potential countries
trade <- trade %>%
  full_join(data.frame(Origin = country.coverage)) %>%
  full_join(data.frame(Destination = country.coverage))


# Copy 2014 into 2015..2019
trade <- bind_rows(
  trade,
  trade %>%
    filter(Year == 2014) %>%
    mutate(Year = 2015))

M.trade <- reshape2::acast(trade, Origin ~ Destination ~ Year, value.var = "ExportsToDestination")


dim(M.trade)
length(countries)

## Remove missing last year in the matrix
#M.trade <- M.trade[,,1:length(time.span)]
#
#match(dimnames(M.trade)[[1]], country.coverage)
#M.trade <- M.trade[match(country.coverage, dimnames(M.trade)[[1]]),
#                       match(country.coverage, dimnames(M.trade)[[2]]),]
#
#dimnames(M.trade)[[1]] == country.coverage
#
#stopifnot(dimnames(M.trade)[[1]] == country.coverage)
#stopifnot(dimnames(M.trade)[[2]] == country.coverage)



#################################
#
# Trade competitors are the countries that export to the same countries
# that are your importers
#
# So first we need the trade imports
# Then the trade exports

#  Trade competitors needs to be calculated weighting both imports and exports
# But it needs to be done when the outcome variable is passed.
trade.p <- trade %>%
  group_by(Origin, Year) %>%
  mutate(p.Exports = ExportsToDestination / sum(ExportsToDestination, na.rm = TRUE),
         p.Imports = ImportsFromDestination / sum(ImportsFromDestination, na.rm = TRUE)) %>%
  ungroup() %>%
  select(Origin, Destination, Year, p.Exports, p.Imports)

M.trade.imports <- reshape2::acast(trade, Origin ~ Destination ~ Year, value.var = "ImportsFromDestination")




save(M.trade, M.trade.imports, trade.p, file = "trade.RData")

