#!/usr/bin/R

# Xavier Fernández i Marín
# http://xavier-fim.net
# dl jun 25 07:03:44 CEST 2018

library(dplyr)
library(tidyr)

file <- "V-Dem-CY-Full+Others-v9.rds"
# file comes from "Country_Year_V-Dem_Full+others_R_v9.zip"
# which is the full set of data for V-Dem v9
d.raw <- readRDS(file)
format(object.size(d.raw), "Mb")
dim(d.raw)
str(d.raw)

# Delete variables that are not the 5 relevant ones
d <- d.raw %>%
  select(Country = country_name, iso3c = country_text_id, COWcode,
         Year = year,
         Electoral = v2x_polyarchy,
         Liberal = v2x_libdem,
         Participatory = v2x_partipdem,
         Deliberative = v2x_delibdem,
         Egalitarian = v2x_egaldem) %>%
  as_tibble()
dim(d)

# Compress / Minimize / arrange the format of the variables
str(d)
d <- d %>%
  mutate(Country = factor(Country)) %>%
  mutate(iso3c = factor(iso3c)) %>%
  mutate(Year = as.integer(Year))
str(d)


# Delete all observations that do not belong to the period 1950-onwards
d <- d %>%
  filter(Year >= 1950)
dim(d)

# Convert it into long format
d <- d %>%
  gather(Democracy, value, -Country, -iso3c, -COWcode, -Year)
dim(d)

############ What to do with countries that appear more than once
### Germany and Czech Republic
### Germany (East) is COWcode 255
### Czechoslovakia is COWcode 315
###
d %>%
  select(Country, COWcode) %>%
  unique() %>%
  group_by(Country) %>%
  summarize(N = n()) %>%
  filter(N > 1)

d %>%
  select(Country, COWcode) %>%
  unique() %>%
  filter(Country %in% c("Czech Republic", "Germany"))

d <- d %>%
  mutate(Country = as.character(Country)) %>%
  mutate(Country = ifelse(COWcode == 315, "Czechoslovakia", Country)) %>%
  mutate(Country = ifelse(COWcode == 255, "Germany (RDA)", Country)) %>%
  mutate(Country = factor(Country))


### Therefore, forget about the COWcode as a grouping variable
d <- d %>%
  ungroup() %>%
  select(-COWcode)



##############################
#
## Define specific periods and calculate country means for every period
#d.p <- d %>%
#  mutate(`1990-2010` = ifelse(Year >= 1990 & Year <= 2010, TRUE, FALSE)) %>%
#  mutate(`1990-1999` = ifelse(Year >= 1990 & Year <= 1999, TRUE, FALSE)) %>%
#  mutate(`2000-2010` = ifelse(Year >= 2000 & Year <= 2010, TRUE, FALSE)) %>%
#  mutate(`2005-2010` = ifelse(Year >= 2005 & Year <= 2010, TRUE, FALSE)) %>%
#  mutate(`2009` = ifelse(Year == 2009, TRUE, FALSE)) %>%
#  gather(Period, period, `1990-2010`, `1990-1999`, `2000-2010`, `2005-2010`, `2009`) %>%
#  filter(period) %>%
#  select(-period)
#dim(d.p)  
#
## Calculate means for every period
#dm <- d.p %>%
#  group_by(Country, iso3c, Democracy, Period) %>%
#  summarize(Mean = mean(value), Median = median(value)) %>%
#  ungroup() %>%
#  mutate(Democracy = as.factor(Democracy)) %>%
#  mutate(Period = as.factor(Period))
#dim(dm)
#
#
## Calculate differences of democracy levels
## Assess democratization processes
#dz <- d %>%
#  spread(Year, value) %>%
#  mutate(`Diff 2010-1990` = `2010`-`1990`) %>%
#  mutate(`Diff 2010-2005` = `2010`-`2005`) %>%
#  mutate(`Diff 2010-2000` = `2010`-`2000`) %>%
#  mutate(`Diff 2000-1990` = `2000`-`1990`) %>%
#  select(Country, iso3c, Democracy,
#         `Diff 2010-1990`, `Diff 2010-2005`,
#         `Diff 2010-2000`, `Diff 2000-1990`) %>%
#  gather(Period, value, -Country, -iso3c, -Democracy)


# dm: means and medians for different time periods
# dz: differences, democratization processes
#save(dm, dz, file = "v_dem-ra-1950_2018.RData")


vdem <- d
save(vdem, file = "v_dem-ra-1950_2018.RData")

