library(WDI)
library(dplyr)
library(countrycode)
load("details.RData")

# Get "GDP (constant 2005 US$)", NY.GDP.MKTP.KD
#gdp <- WDI(indicator="NY.GDP.MKTP.KD", 
# Get "GDP (current US$), NY.GDP.MKTP.CD
gdp <- WDI(indicator="NY.GDP.MKTP.CD",
  country='all',
  start=1975, end=2005)
names(gdp)[3] <- "gdp"

# Get "Population (Total)", SP.POP.TOTL
pop <- WDI(indicator="SP.POP.TOTL", 
  country='all',
  start=1975, end=2005)
names(pop)[3] <- "population"

# Get GDP per capita at constant 2000 US$
# "NY.GDP.PCAP.KD" "GDP per capita (constant 2000 US$)"
gdp.capita <- WDI(indicator="NY.GDP.PCAP.KD", 
  country='all',
  start=1975, end=2005)
names(gdp.capita)[3] <- "gdp.capita"


# Get proportion of GDP of imports/exports of goods and services
#"NE.IMP.GNFS.ZS" "Imports of goods and services (% of GDP)"
#"NE.EXP.GNFS.ZS" "Exports of goods and services (% of GDP)"
imports <- WDI(indicator="NE.IMP.GNFS.ZS", 
  country='all',
  start=1975, end=2005)
names(imports)[3] <- "imports"

exports <- WDI(indicator="NE.EXP.GNFS.ZS", 
  country='all',
  start=1975, end=2005)
names(exports)[3] <- "exports"


# Get the proportion of trade over GDP
# "NE.TRD.GNFS.ZS" "Trade (% of GDP)"
trade <- WDI(indicator="NE.TRD.GNFS.ZS", 
  country='all',
  start=1975, end=2005)
names(trade)[3] <- "trade"



# GDP, population and GDP per capita
wdi <- merge(gdp, pop)
wdi <- merge(wdi, gdp.capita)

# Sum of proportion of imports and exports
wdi <- merge(wdi, imports)
wdi <- merge(wdi, exports)
wdi <- cbind(wdi, sum.imp.exp=wdi$imports + wdi$exports)

# Trade
wdi <- merge(wdi, trade)


save(wdi, file="wdi.RData")


## Extra WDI data

countries.iso2c <- countrycode(countries, origin = "country.name", destination = "iso2c")

tax.rev <- WDI(indicator = "GC.TAX.TOTL.GD.ZS", 
               country = countries.iso2c,
               start = years[1], end = years[2])

save(tax.rev, file = "wdi-tax.RData")

# GDP growth
gdp.growth <- WDI(indicator = "NY.GDP.MKTP.KD.ZG", # "GNP growth (annual %)"
               country = countries.iso2c,
               start = years[1], end = years[2])

save(gdp.growth, file = "wdi-gdpgrowth.RData")


# Urban population
urban <- WDI(indicator = "SP.URB.TOTL.IN.ZS", # Urban population (% of total)
               country = countries.iso2c,
               start = years[1], end = years[2])

save(urban, file = "wdi-urban.RData")


# Industry share
industry <- WDI(indicator = "NV.IND.TOTL.ZS", # "Industry (including construction), value added (% of GDP)"
               country = countries.iso2c,
               start = years[1], end = years[2])

save(industry, file = "wdi-industry.RData")



