#!/usr/bin/R

# Xavier Fernández i Marín
# http://xavier-fim.net
# dv jun 20 18:16:55 CEST 2014

rm(list=ls())
library(xlsx)
library(countrycode)


# Sheet labels, starting from sheet number 2
sheets <- c(
  "Voice and Accountability",
  "Political Stability and Absence of Violence/Terrorism",
  "Government effectiveness",
  "Regulatory Quality",
  "Rule of Law",
  "Control of Corruption")


# Test one sheet and also get country names
date <- "201029"
d1 <- read.xlsx(paste(date, "-wgidataset.xlsx", sep = ""), sheetIndex=2, startRow=15)
str(d1)
countries <- d1[,1:2]
names(countries) <- c("country.capital", "country.code")
countries$country <- countrycode(countries$country.code, "wb", "country.name")


# Specify values to retrieve, years and their lengths
variables <- c("value", "se", "n.sources", "rank", "lower", "upper")
years <- c(seq(1996, 2002, by=2), 2003:2018)
Y <- length(years)
V <- length(variables)


# Process a specified sheet, defined by a position in the file and by a label
# Generate a data frame with country.code, year, indicator, estimate of the
# value and standard error, and also number of sources that have lead to that
# specific value for the country and year.
#
# Rank, lower and upper boundaries are discarded
#
# Country codes are preferred over country names because country names are all
# capitals and do not match any known code, and country code can be used with
# package "countrycodes"

process.sheet <- function(sheet, sheet.label, date = date) {
  d <- NULL
  ds <- readxl::read_excel(paste(date, "-wgidataset.xlsx", sep = ""), 
                  sheet = sheet, skip = 14, 
                  na = "#N/A", .name_repair = "minimal")
  for (y in 1:Y) {
    message(paste("Processing year ", y, "/", Y, sep = ""))
    d <- rbind(d, data.frame(
      country.code = ds$Code,
      year = years[y],
      indicator = sheet.label,
      value.estimate = ds[,3+(6*(y-1))],
      value.se = ds[,4+(6*(y-1))])
    )
  }
  return(d)
}


# Loop over sheets and process one by one
D <- NULL
for (s in 1:length(sheets)) {
  message(paste("Processing sheet ", s, "/", length(sheets), sep = ""))
  D <- rbind(D, process.sheet(sheet=s+1, sheet.label=sheets[s], date = date))
}

str(D)
dim(D)
format(object.size(D), units="Mb")

# Add country names and delete country codes
D <- merge(countries, D)
#D <- D[,-c(1, 2)] # get rid of country code and capitalized country name
D <- D[,-c(2)] # get rid of capitalized country name

# Optimize types of the columns
D$country <- as.factor(D$country)
D$year <- as.integer(D$year)


# Rename and save
# The date of the revision can be found at the end of the first sheet (Introduction) of the xlsx file
wgi <- D
save(wgi, file = paste("wgi-full-v", date, ".RData", sep = ""))

